@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Passphrase;
-$Mojolicious::Plugin::Passphrase::VERSION = '0.002';
+$Mojolicious::Plugin::Passphrase::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -47,7 +47,7 @@ Mojolicious::Plugin::Passphrase - Securely hash and validate your passwords.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -61,7 +61,7 @@ version 0.002
  sub startup {
    my $self = shift;
 
-   $self->plugin(Passphrase => { encoder => 'Argon2'});
+   $self->plugin(Passphrase => { encoder => 'Argon2' });
  }
 
 =head1 DESCRIPTION
@@ -92,7 +92,7 @@ Checks if a hash needs rehashing.
 
  if ($c->verify_password($plaintext_password, $crypted_password)) {
    if ($c->password_needs_rehash($crypted_password)) {
-     my $new_hash = c->hash_password($plaintext_password);
+     my $new_hash = $c->hash_password($plaintext_password);
      # store new hash to the database
    }
  }
